@@ -1,6 +1,6 @@
-"""Programtype Schema"""
+"""Load Schemas"""
 from pydantic import Field, root_validator, constr
-from typing import Union
+from typing import Union, List
 
 from ._base import IDdEnergyBaseModel
 from .schedule import ScheduleRuleset, ScheduleFixedInterval
@@ -28,21 +28,23 @@ class PeopleAbridged(IDdEnergyBaseModel):
     )
 
     activity_schedule: str = Field(
-        ...,
+        default=None,
         min_length=1,
         max_length=100,
-        description='Identifier of a schedule for the activity of the occupants over the '
-        'course of the year. The type of this schedule should be Power and the '
-        'values of the schedule equal to the number of Watts given off by an '
-        'individual person in the room.'
+        description='Identifier of a schedule for the activity of the occupants over '
+        'the course of the year. The type of this schedule should be ActivityLevel '
+        'and the values of the schedule equal to the number of Watts given off by an '
+        'individual person in the room. If None, a default constant schedule with '
+        '120 Watts per person will be used, which is typical of awake, adult humans '
+        'who are seated.'
     )
 
     radiant_fraction: float = Field(
         0.3,
         ge=0,
         le=1,
-        description='The radiant fraction of sensible heat released by people. The default'
-        'value is 0.30.'
+        description='The radiant fraction of sensible heat released by people. '
+        '(Default: 0.3).'
     )
 
     latent_fraction: Union[Autocalculate, float] = Field(
@@ -77,11 +79,13 @@ class People(PeopleAbridged):
     )
 
     activity_schedule: Union[ScheduleRuleset, ScheduleFixedInterval] = Field(
-        ...,
+        default=None,
         description='A schedule for the activity of the occupants over the '
-        'course of the year. The type of this schedule should be Power and the '
-        'values of the schedule equal to the number of Watts given off by an '
-        'individual person in the room.'
+        'course of the year. The type of this schedule should be ActivityLevel '
+        'and the values of the schedule equal to the number of Watts given off by an '
+        'individual person in the room. If None, a default constant schedule with '
+        '120 Watts per person will be used, which is typical of awake, adult humans '
+        'who are seated.'
     )
 
 
@@ -99,8 +103,8 @@ class LightingAbridged(IDdEnergyBaseModel):
         ...,
         min_length=1,
         max_length=100,
-        description='Identifier of the schedule for the use of lights over the course of '
-        'the year. The type of this schedule should be Fractional and the '
+        description='Identifier of the schedule for the use of lights over the course '
+        'of the year. The type of this schedule should be Fractional and the '
         'fractional values will get multiplied by the watts_per_area to yield a '
         'complete lighting profile.'
     )
@@ -109,24 +113,24 @@ class LightingAbridged(IDdEnergyBaseModel):
         0.25,
         ge=0,
         le=1,
-        description='The fraction of heat from lights that goes into the zone as visible '
-        '(short-wave) radiation. The default value is `0.25`.'
+        description='The fraction of heat from lights that goes into the zone as '
+        'visible (short-wave) radiation. (Default: 0.25).'
     )
 
     radiant_fraction: float = Field(
         0.32,
         ge=0,
         le=1,
-        description='The fraction of heat from lights that is long-wave radiation. Default'
-        ' value is `0.32`.'
+        description='The fraction of heat from lights that is long-wave radiation. '
+        '(Default: 0.32).'
     )
 
     return_air_fraction: float = Field(
         0.0,
         ge=0,
         le=1,
-        description='The fraction of the heat from lights that goes into the zone return '
-        'air. Default value is `0`.'
+        description='The fraction of the heat from lights that goes into the zone '
+        'return air. (Default: 0).'
     )
 
     baseline_watts_per_area: float = Field(
@@ -175,8 +179,8 @@ class _EquipmentBase(IDdEnergyBaseModel):
         ...,
         min_length=1,
         max_length=100,
-        description='Identifier of the schedule for the use of equipment over the course '
-        'of the year. The type of this schedule should be Fractional and the '
+        description='Identifier of the schedule for the use of equipment over the '
+        'course of the year. The type of this schedule should be Fractional and the '
         'fractional values will get multiplied by the watts_per_area to yield '
         'a complete equipment profile.'
     )
