@@ -1,42 +1,15 @@
 """SensorGrid and Sensor Schema"""
-from pydantic import Field, constr, validator
+from pydantic import Field, constr
 from typing import List
 from enum import Enum
-from ..geometry import Mesh3D
+from ..geometry import Mesh3D, Face3D
 from .._base import NoExtraBaseModel
 from ._base import IDdRadianceBaseModel
 
-import re
-
 
 class _RadianceAsset(IDdRadianceBaseModel):
     """Hidden base class for all Radiance Assets."""
 
-    display_name: str = Field(
-        default=None,
-        description='Text string for a unique display name, used to set the default '
-        'file name that the radiance asset is written to within a radiance folder. '
-        'Must not contain spaces or special characters.'
-    )
-
-    @validator('display_name')
-    def valid_rad_string_display_name(cls, value):
-        """Check that a string is valid for Radiance.
-
-        This method is modified from the honeybee-core.typing.valid_rad_string method.
-        """
-        if value is not None:
-            try:
-                illegal_match = re.search(r'[^.A-Za-z0-9_-]', value)
-            except TypeError:
-                raise TypeError('display_name must be a text string. Got {}: {}.'.format(
-                    type(value), value))
-            assert illegal_match is None, \
-                'Illegal character "{}" found in display_name'.format(illegal_match.group(0))
-            assert len(value) > 0, \
-                'Input display_name "{}" contains no characters.'.format(value)
-        return value
-
     room_identifier: str = Field(
         None,
         regex=r'[A-Za-z0-9_-]',
@@ -96,6 +69,22 @@ class SensorGrid(_RadianceAsset):
         'the Mesh3D.'
     )
 
+    base_geometry: List[Face3D] = Field(
+        None,
+        description='An optional array of Face3D used to represent the grid. '
+        'There are no restrictions on how this property relates to the sensors and it '
+        'is provided only to assist with the display of the grid when the number '
+        'of sensors or the mesh is too large to be practically visualized.'
+    )
+
+    group_identifier: str = Field(
+        default=None,
+        description="An optional string to note the sensor grid group ' \
+            'to which the sensor is a part of. Grids sharing the same ' \
+            'group_identifier will be written to the same subfolder in Radiance ' \
+            'folder (default: None)."
+    )
+
 
 class ViewType(str, Enum):
     """A single character for the view type (-vt)."""
@@ -192,3 +181,11 @@ class View(_RadianceAsset):
         'view types, the clipping plane is actually a clipping sphere, '
         'centered on the view point with radius val.'
     )
+
+    group_identifier: str = Field(
+        default=None,
+        description="An optional string to note the view group ' \
+            'to which the sensor is a part of. Views sharing the same ' \
+            'group_identifier will be written to the same subfolder in Radiance ' \
+            'folder (default: None)."
+    )
