@@ -8,7 +8,7 @@ from ._base import IDdRadianceBaseModel
 class Void(BaseModel):
     """Void modifier"""
 
-    type: constr(regex='^void$') = 'void'
+    type: constr(regex='^Void$') = 'Void'
 
 
 class ModifierBase(IDdRadianceBaseModel):
@@ -20,96 +20,88 @@ class ModifierBase(IDdRadianceBaseModel):
 class Mirror(ModifierBase):
     """Radiance mirror material."""
 
-    type: constr(regex='^mirror$') = 'mirror'
+    type: constr(regex='^Mirror$') = 'Mirror'
 
     modifier: Optional[_REFERENCE_UNION_MODIFIERS] = Field(
         default=Void(),
-        description='Material modifier (default: Void).'
+        description='Material modifier.'
     )
 
     dependencies: List[_REFERENCE_UNION_MODIFIERS] = Field(
         default=None,
-        description='List of modifiers that this modifier depends on. '
-                    'This argument is only useful for defining advanced modifiers '
-                    'where the modifier is defined based on other modifiers '
-                    '(default: None).'
+        description='List of modifiers that this modifier depends on. This argument '
+        'is only useful for defining advanced modifiers where the modifier is defined '
+        'based on other modifiers.'
     )
 
     r_reflectance: float = Field(
         default=1,
         ge=0,
         le=1,
-        description='A value between 0 and 1 for the red channel reflectance '
-                    '(default: 1).'
+        description='A value between 0 and 1 for the red channel reflectance.'
     )
 
     g_reflectance: float = Field(
         default=1,
         ge=0,
         le=1,
-        description='A value between 0 and 1 for the green channel reflectance '
-                    '(default: 1).'
+        description='A value between 0 and 1 for the green channel reflectance.'
     )
 
     b_reflectance: float = Field(
         default=1,
         ge=0,
         le=1,
-        description='A value between 0 and 1 for the blue channel reflectance '
-                    '(default: 1).'
+        description='A value between 0 and 1 for the blue channel reflectance.'
     )
 
     alternate_material: _REFERENCE_UNION_MODIFIERS = Field(
         default=None,
-        description='An optional material that may be used like the illum type to '
+        description='An optional material (like the illum type) that may be used to '
         'specify a different material to be used for shading non-source rays. '
         'If None, this will keep the alternat_material as mirror. If this alternate '
         'material is given as Void, then the mirror surface will be invisible. '
         'Using Void is only appropriate if the surface hides other (more '
-        'detailed) geometry with the same overall reflectance (default: None).'
+        'detailed) geometry with the same overall reflectance.'
     )
 
 
 class Plastic(ModifierBase):
     """Radiance plastic material."""
 
-    type: constr(regex='^plastic$') = 'plastic'
+    type: constr(regex='^Plastic$') = 'Plastic'
 
     modifier: Optional[_REFERENCE_UNION_MODIFIERS] = Field(
         default=Void(),
-        description='Material modifier (default: Void).'
+        description='Material modifier.'
     )
 
     dependencies: List[_REFERENCE_UNION_MODIFIERS] = Field(
         default=None,
-        description='List of modifiers that this modifier depends on. '
-                    'This argument is only useful for defining advanced modifiers '
-                    'where the modifier is defined based on other modifiers '
-                    '(default: None).'
+        description='List of modifiers that this modifier depends on. This argument '
+        'is only useful for defining advanced modifiers where the modifier is defined '
+        'based on other modifiers.'
     )
 
     r_reflectance: float = Field(
         default=0.0,
         ge=0,
         le=1,
-        description='A value between 0 and 1 for the red channel reflectance '
-                    '(default: 0).'
+        description='A value between 0 and 1 for the red channel reflectance.'
     )
 
     g_reflectance: float = Field(
         default=0.0,
         ge=0,
         le=1,
-        description='A value between 0 and 1 for the green channel reflectance '
-                    '(default: 0).'
+        description='A value between 0 and 1 for the green channel reflectance.'
     )
 
     b_reflectance: float = Field(
         default=0.0,
         ge=0,
         le=1,
-        description='A value between 0 and 1 for the blue channel reflectance '
-                    '(default: 0).'
+        description='A value between 0 and 1 for the blue channel reflectance.'
     )
 
     specularity: float = Field(
@@ -117,8 +109,8 @@ class Plastic(ModifierBase):
         ge=0,
         le=1,
         description='A value between 0 and 1 for the fraction of specularity. '
-                    'Specularity fractions greater than 0.1 are not realistic '
-                    'for non-metallic materials. (default: 0).'
+        'Specularity fractions greater than 0.1 are not realistic for non-metallic '
+        'materials.'
     )
 
     roughness: float = Field(
@@ -126,45 +118,42 @@ class Plastic(ModifierBase):
         ge=0,
         le=1,
         description='A value between 0 and 1 for the roughness, specified as the '
-                    'rms slope of surface facets. Roughness greater than 0.2 are '
-                    'not realistic (default: 0).'
+        'RMS slope of surface facets. Roughness greater than 0.2 are not realistic.'
     )
 
 
 class Metal(Plastic):
     """Radiance metal material."""
 
-    type: constr(regex='^metal$') = 'metal'
+    type: constr(regex='^Metal$') = 'Metal'
 
     specularity: float = Field(
         default=0.9,
         ge=0,
         le=1,
         description='A value between 0 and 1 for the fraction of specularity. '
-                    'Specularity fractions lower than 0.9 are not realistic for '
-                    'metallic materials. (default: 0.9).'
+        'Specularity fractions lower than 0.9 are not realistic for metallic materials.'
     )
 
 
 class Trans(Plastic):
     """Radiance Translucent material."""
 
-    type: constr(regex='^trans$') = 'trans'
+    type: constr(regex='^Trans$') = 'Trans'
 
     transmitted_diff: float = Field(
         default=0,
         ge=0,
         le=1,
         description='The fraction of transmitted light that is transmitted diffusely in '
-                    'a scattering fashion (default: 0).'
+        'a scattering fashion.'
     )
 
     transmitted_spec: float = Field(
         default=0,
         ge=0,
         le=1,
-        description='The fraction of transmitted light that is not diffusely scattered '
-                    '(default: 0).'
+        description='The fraction of transmitted light that is not diffusely scattered.'
     )
 
     @root_validator
@@ -186,50 +175,45 @@ class Trans(Plastic):
 class Glass(ModifierBase):
     """Radiance glass material."""
 
-    type: constr(regex='^glass$') = 'glass'
+    type: constr(regex='^Glass$') = 'Glass'
 
     modifier: Optional[_REFERENCE_UNION_MODIFIERS] = Field(
         default=Void(),
-        description='Material modifier (default: Void).'
+        description='Material modifier.'
     )
 
     dependencies: List[_REFERENCE_UNION_MODIFIERS] = Field(
         default=None,
-        description='List of modifiers that this modifier depends on. '
-                    'This argument is only useful for defining advanced modifiers '
-                    'where the modifier is defined based on other modifiers '
-                    '(default: None).'
+        description='List of modifiers that this modifier depends on. This argument '
+        'is only useful for defining advanced modifiers where the modifier is '
+        'defined based on other modifiers.'
     )
 
     r_transmissivity: float = Field(
         default=0.0,
         ge=0,
         le=1,
-        description='A value between 0 and 1 for the red channel transmissivity '
-                    '(default: 0).'
+        description='A value between 0 and 1 for the red channel transmissivity.'
     )
 
     g_transmissivity: float = Field(
         default=0.0,
         ge=0,
         le=1,
-        description='A value between 0 and 1 for the green channel transmissivity '
-                    '(default: 0).'
+        description='A value between 0 and 1 for the green channel transmissivity.'
     )
 
     b_transmissivity: float = Field(
         default=0.0,
         ge=0,
         le=1,
-        description='A value between 0 and 1 for the blue channel transmissivity '
-                    '(default: 0).'
+        description='A value between 0 and 1 for the blue channel transmissivity.'
     )
 
     refraction_index: Optional[float] = Field(
         default=1.52,
         ge=0,
-        description='A value between 0 and 1 for the index of refraction '
-                    '(default: 1.52).'
+        description='A value between 0 and 1 for the index of refraction.'
     )
 
 
@@ -240,38 +224,38 @@ class BSDF(ModifierBase):
 
     modifier: Optional[_REFERENCE_UNION_MODIFIERS] = Field(
         default=Void(),
-        description='Material modifier (default: Void).'
+        description='Material modifier.'
     )
 
     dependencies: List[_REFERENCE_UNION_MODIFIERS] = Field(
         default=None,
-        description='List of modifiers that this modifier depends on. '
-                    'This argument is only useful for defining advanced modifiers '
-                    'where the modifier is defined based on other modifiers '
-                    '(default: None).'
+        description='List of modifiers that this modifier depends on. This argument '
+        'is only useful for defining advanced modifiers where the modifier is defined '
+        'based on other modifiers.'
     )
 
     up_orientation: List[float] = Field(
         default=(0.01, 0.01, 1.00),
         min_items=3,
         max_items=3,
-        description='Vector as sequence that sets the hemisphere that the BSDF material '
-                    'faces. (default: (0.01, 0.01, 1.00).'
+        description='Vector as sequence that sets the hemisphere that the BSDF '
+        'material faces.'
     )
 
     thickness: float = Field(
         default=0,
         description='Optional number to set the thickness of the BSDF material '
-                    'Sign of thickness indicates whether proxied geometry is '
-                    'behind the BSDF surface (when thickness is positive) or in '
-                    'front (when thickness is negative)(default: 0).'
+        'Sign of thickness indicates whether proxied geometry is behind the BSDF '
+        'surface (when thickness is positive) or in front (when thickness is '
+        'negative).'
     )
 
     function_file: str = Field(
         default='.',
         min_length=1,
         max_length=100,
-        description='Optional input for function file (default: ".").'
+        description='Optional input for function file. Using "." will ensure that '
+        'BSDF data is written to the root of wherever a given study is run.'
     )
 
     transform: str = Field(
@@ -279,7 +263,7 @@ class BSDF(ModifierBase):
         min_length=1,
         max_length=100,
         description='Optional transform input to scale the thickness and reorient '
-                    'the up vector (default: None).'
+        'the up vector.'
     )
 
     bsdf_data: str = Field(
@@ -292,7 +276,7 @@ class BSDF(ModifierBase):
         min_items=3,
         max_items=3,
         description='Optional additional front diffuse reflectance as sequence of '
-                    'numbers (default: None).'
+        'three RGB numbers.'
     )
 
     back_diffuse_reflectance: List[float] = Field(
@@ -300,7 +284,7 @@ class BSDF(ModifierBase):
         min_items=3,
         max_items=3,
         description='Optional additional back diffuse reflectance as sequence of '
-                    'numbers (default: None).'
+        'three RGB numbers.'
     )
 
     diffuse_transmittance: List[float] = Field(
@@ -308,7 +292,7 @@ class BSDF(ModifierBase):
         min_items=3,
         max_items=3,
         description='Optional additional diffuse transmittance as sequence of '
-                    'numbers (default: None).'
+        'three RGB numbers.'
     )
 
     @validator('front_diffuse_reflectance')
@@ -336,57 +320,53 @@ class BSDF(ModifierBase):
 class Light(ModifierBase):
     """Radiance Light material."""
 
-    type: constr(regex='^light$') = 'light'
+    type: constr(regex='^Light$') = 'Light'
 
     modifier: Optional[_REFERENCE_UNION_MODIFIERS] = Field(
         default=Void(),
-        description='Material modifier (default: Void).'
+        description='Material modifier.'
     )
 
     dependencies: List[_REFERENCE_UNION_MODIFIERS] = Field(
         default=None,
-        description='List of modifiers that this modifier depends on. '
-                    'This argument is only useful for defining advanced modifiers '
-                    'where the modifier is defined based on other modifiers '
-                    '(default: None).'
+        description='List of modifiers that this modifier depends on. This argument '
+        'is only useful for defining advanced modifiers where the modifier is '
+        'defined based on other modifiers.'
     )
 
     r_emittance: float = Field(
         default=0.0,
         ge=0,
         le=1,
-        description='A value between 0 and 1 for the red channel of the modifier '
-                    '(default: 0).'
+        description='A value between 0 and 1 for the red channel of the modifier.'
     )
 
     g_emittance: float = Field(
         default=0.0,
         ge=0,
         le=1,
-        description='A value between 0 and 1 for the green channel of the modifier '
-                    '(default: 0).'
+        description='A value between 0 and 1 for the green channel of the modifier.'
     )
 
     b_emittance: float = Field(
         default=0.0,
         ge=0,
         le=1,
-        description='A value between 0 and 1 for the blue channel of the modifier '
-                    '(default: 0).'
+        description='A value between 0 and 1 for the blue channel of the modifier.'
     )
 
 
 class Glow(Light):
     """Radiance Glow material."""
 
-    type: constr(regex='^glow$') = 'glow'
+    type: constr(regex='^Glow$') = 'Glow'
 
     max_radius: float = Field(
         default=0,
-        description='Maximum radius for shadow testing (default: 0). Surfaces with zero '
-                    'will never be tested for zero, although it may participate in '
-                    'interreflection calculation. Negative values will never contribute '
-                    'to scene illumination.'
+        description='Maximum radius for shadow testing. Objects with zero radius '
+        'are permissable and may participate in interreflection calculation (though '
+        'they are not representative of real light sources). Negative values will '
+        'never contribute to scene illumination.'
     )
 
 
