@@ -1,6 +1,6 @@
 from honeybee_schema.energy.hvac.idealair import IdealAirSystemAbridged
 from honeybee_schema.energy.hvac.allair import VAV
-from honeybee_schema.energy.hvac.doas import FCUwithDOAS
+from honeybee_schema.energy.hvac.doas import FCUwithDOASAbridged
 from honeybee_schema.energy.hvac.heatcool import WindowAC
 import os
 
@@ -26,7 +26,7 @@ def test_vav_template():
 
 def test_fcu_with_doas_template():
     file_path = os.path.join(target_folder, 'fcu_with_doas_template.json')
-    FCUwithDOAS.parse_file(file_path)
+    FCUwithDOASAbridged.parse_file(file_path)
 
 
 def test_window_ac_with_baseboard_template():
